from thd_json import Validator

from pathlib import Path
import argparse


def get_header_validator(json_suffix: str = '*.json') -> Validator:
    return Validator(Path(__file__).parent / Path('header.json'), json_suffix)

def header_cli():
    parser = argparse.ArgumentParser(description='JSON THD Header Validator CLI with uv.')
    parser.add_argument('folder', help='Folder to check.', type=str)
    parser.add_argument('suffix', help='Projection suffix.', default='*.json', type=Path, nargs='?')
    args = parser.parse_args()

    suffix = str(args.suffix)
    if not suffix.startswith('*'):
        raise ValueError(f'The suffix must always start with: "*". \nIt is: {suffix}')

    validator = get_header_validator(
        suffix)
    
    folder = Path(args.folder)
    if not folder.exists():
        raise FileNotFoundError(f'Folder: {folder} does not exist')

    validator.folder(Path(args.folder))


if __name__ == "__main__":
    header_cli()