import os
import json
from pathlib import Path
from jsonschema import ValidationError, RefResolver
from jsonschema.validators import Draft202012Validator
import os


class Validator():
    def __init__(self, json_schema: Path, json_suffix: str = '*.json') -> None:
        self.json_schema = json_schema
        self.json_suffix = json_suffix
        print(f"Validator for schema: {json_schema} \nSuffix: {json_suffix}\n")

    def file(self, file_path: Path) -> bool:
        with open(str(self.json_schema)) as schema_file, open(str(file_path)) as data_file:
            schema = json.load(schema_file)
            data = json.load(data_file)
            try:
                schema_path = self.json_schema.parent.absolute().as_uri()
                resolver = RefResolver(base_uri=schema_path,
                                       referrer=schema)
                Draft202012Validator(schema=schema,
                                     format_checker=Draft202012Validator.FORMAT_CHECKER,
                                     resolver=resolver).validate(data)
                print(f"Validate file: {file_path.parent} / {file_path.name}\n")
                
            except ValidationError as e:
                print("Validation error:", e)

        return True
    
    def folder(self, folder_path: Path) -> bool:
        print(f"Validate folder: {folder_path}\n")
        for file in folder_path.glob(self.json_suffix):
            self.file(file)
        return True